Welcome to django SHOP’s documentation! — django SHOP 0.1.1.dev0 documentation

### Navigation

- index
- modules |
- next |
- django SHOP 0.1.1.dev0 documentation »

# Welcome to django SHOP’s documentation!

## User Manual

The “instructions” :)

- 1. Tutorial
- 2. Getting started
- 3. Templatetags
- 4. Signals
- 5. Contributing

## How to

Various short articles on how to do specific things

- 1. How to create a product
  - 1.1. Create a model
  - 1.2. Create a template
  - 1.3. Using your newly created Product
  - 1.4. Product variations
- 2. How to create a Cart modifier
  - 2.1. Writing a simple cart modifier for the whole cart
- 3. How to create a Payment backend
  - 3.1. Shop interface
  - 3.2. Backend interface
- 4. How to create a shipping backend
  - 4.1. Shop interface
  - 4.2. Backend interface
- 5. How to interact with the cart
  - 5.1. Updating the whole cart
  - 5.2. Emptying the cart
- 6. How to secure your views
  - 6.1. @on_method decorator
  - 6.2. @shop_login_required decorator
  - 6.3. LoginMixin class

## Advanced how to

More focused short articles, focusing on less general and more advanced use cases.

- 1. How to extend django SHOP models
  - 1.1. Example
  - 1.2. Settings
- 2. How to use your own addressmodel
  - 2.1. Deactivate the default addressmodel
  - 2.2. Hook your own model to the shop

## Reference

Reference sheets and lists regarding django SHOP

- 1. Plugins
- 2. General Settings
- 3. Backend specific Settings
- 4. Extensibility Settings

## The name

The official name of this project is django SHOP.

Django SHOP should be capitalised at the start of sentences and in title-case headings.

When referring to the package, repositories and any other things in which spaces are not permitted, use django-shop.

### Navigation

- index
- modules |
- next |
- django SHOP 0.1.1.dev0 documentation »